Struct resize::px::RGBA [−][src]
The RGBA pixel
The component type can be u8 (aliased as RGBA8), u16 (aliased as RGBA16),
or any other type (but simple copyable types are recommended.)
You can specify a different type for alpha, but it’s only for special cases
(e.g. if you use a newtype like RGBA<LinearLight<u16>, u16>).
Fields
r: ComponentTypeRed
g: ComponentTypeGreen
b: ComponentTypeBlue
a: AlphaComponentTypeAlpha
Implementations
impl<T> RGBA<T, T>[src]
pub const fn new(r: T, g: T, b: T, a: T) -> RGBA<T, T>[src]
Convenience function for creating a new pixel The order of arguments is R,G,B,A
impl<T, A> RGBA<T, A>[src]
pub const fn new_alpha(r: T, g: T, b: T, a: A) -> RGBA<T, A>[src]
Convenience function for creating a new pixel The order of arguments is R,G,B,A
impl<T, A> RGBA<T, A>[src]
pub fn rgb_mut(&mut self) -> &mut RGB<T>[src]
Provide a mutable view of only RGB components (leaving out alpha). Useful to change color without changing opacity.
impl<T, A> RGBA<T, A> where
T: Clone, [src]
T: Clone,
pub fn rgb(&self) -> RGB<T>[src]
Copy RGB components out of the RGBA struct
Note: you can use .into() to convert between other types
impl<T> RGBA<T, T> where
T: Clone, [src]
T: Clone,
impl<T, A> RGBA<T, A> where
T: Clone, [src]
T: Clone,
pub fn bgr(&self) -> BGR<T>[src]
Copy RGB components out of the RGBA struct
Note: you can use .into() to convert between other types
impl<T, A> RGBA<T, A> where
T: Copy,
A: Clone, [src]
T: Copy,
A: Clone,
pub fn map_rgb<F, U, B>(&self, f: F) -> RGBA<U, B> where
F: FnMut(T) -> U,
B: From<A> + Clone,
U: Clone, [src]
F: FnMut(T) -> U,
B: From<A> + Clone,
U: Clone,
Create new RGBA with the same alpha value, but different RGB values
pub fn alpha(&self, a: A) -> RGBA<T, A>[src]
Create a new RGBA with the new alpha value, but same RGB values
pub fn map_alpha<F, B>(&self, f: F) -> RGBA<T, B> where
F: FnOnce(A) -> B, [src]
F: FnOnce(A) -> B,
Create a new RGBA with a new alpha value created by the callback. Allows changing of the type used for the alpha channel.